@@ -1,6 +1,6 @@
 import json
 import psycopg2
-from adp_connectors.base import Connector
+from .base import Connector
 
 
 class PgConnector(Connector):
